==> vue-pagination-vwi-2.0.8.tgz: package/compiled/template.js <==
'use strict';

var _babelHelperVueJsxMergeProps = require('babel-helper-vue-jsx-merge-props');

var _babelHelperVueJsxMergeProps2 = _interopRequireDefault(_babelHelperVueJsxMergeProps);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = function () {

    return function (h) {
        var _this = this;

        var theme = this.Theme;
        var items = [];
        var prevChunk = '';
        var nextChunk = '';
        var firstPage = '';
        var lastPage = '';

        if (this.opts.edgeNavigation && this.totalChunks > 1) {
            firstPage = h(
                'li',
                { 'class': 'VuePagination__pagination-item ' + theme.item + ' ' + (this.page === 1 ? theme.disabled : '') + ' VuePagination__pagination-item-prev-chunk' },
                [h(
                    'a',
                    (0, _babelHelperVueJsxMergeProps2.default)([{ 'class': theme.link,
                        attrs: { href: 'javascript:void(0);',
                            disabled: this.page === 1
                        }
                    }, {
                        on: {
                            'click': function click($event) {
                                for (var _len = arguments.length, attrs = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
                                    attrs[_key - 1] = arguments[_key];
                                }

                                _this.setPage.bind(_this, 1).apply(undefined, [$event].concat(attrs));
                            }
                        }
                    }]),
                    [this.opts.texts.first]
                )]
            );

            lastPage = h(
                'li',
                { 'class': 'VuePagination__pagination-item ' + theme.item + ' ' + (this.page === this.totalPages ? theme.disabled : '') + ' VuePagination__pagination-item-prev-chunk' },
                [h(
                    'a',
                    (0, _babelHelperVueJsxMergeProps2.default)([{ 'class': theme.link,
                        attrs: { href: 'javascript:void(0);',
                            disabled: this.page === this.totalPages
                        }
                    }, {
                        on: {
                            'click': function click($event) {
                                for (var _len2 = arguments.length, attrs = Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
                                    attrs[_key2 - 1] = arguments[_key2];
                                }

                                _this.setPage.bind(_this, _this.totalPages).apply(undefined, [$event].concat(attrs));
                            }
                        }
                    }]),
                    [this.opts.texts.last]
                )]
            );
        }

        if (this.opts.chunksNavigation && this.opts.chunksNavigation === 'fixed') {

            prevChunk = h(
                'li',
                { 'class': 'VuePagination__pagination-item ' + theme.item + ' ' + theme.prev + ' VuePagination__pagination-item-prev-chunk ' + this.allowedChunkClass(-1) },
                [h(
                    'a',
                    (0, _babelHelperVueJsxMergeProps2.default)([{ 'class': theme.link,
                        attrs: { href: 'javascript:void(0);',
                            disabled: !!this.allowedChunkClass(-1)
                        }
                    }, {
                        on: {
                            'click': function click($event) {
                                for (var _len3 = arguments.length, attrs = Array(_len3 > 1 ? _len3 - 1 : 0), _key3 = 1; _key3 < _len3; _key3++) {
                                    attrs[_key3 - 1] = arguments[_key3];
                                }

                                _this.setChunk.bind(_this, -1).apply(undefined, [$event].concat(attrs));
                            }
                        }
                    }]),
                    ['<<']
                )]
            );

            nextChunk = h(
                'li',
                { 'class': 'VuePagination__pagination-item ' + theme.item + ' ' + theme.next + ' VuePagination__pagination-item-next-chunk ' + this.allowedChunkClass(1) },
                [h(
                    'a',
                    (0, _babelHelperVueJsxMergeProps2.default)([{ 'class': theme.link,
                        attrs: { href: 'javascript:void(0);',
                            disabled: !!this.allowedChunkClass(1)
                        }
                    }, {
                        on: {
                            'click': function click($event) {
                                for (var _len4 = arguments.length, attrs = Array(_len4 > 1 ? _len4 - 1 : 0), _key4 = 1; _key4 < _len4; _key4++) {
                                    attrs[_key4 - 1] = arguments[_key4];
                                }

                                _this.setChunk.bind(_this, 1).apply(undefined, [$event].concat(attrs));
                            }
                        }
                    }]),
                    ['>>']
                )]
            );
        }

        this.pages.map(function (page) {
            var _this2 = this;

            items.push(h(
                'li',
                { 'class': 'VuePagination__pagination-item ' + theme.item + ' ' + this.activeClass(page) },
                [h(
                    'a',
                    (0, _babelHelperVueJsxMergeProps2.default)([{ 'class': theme.link + ' ' + this.activeClass(page),
                        attrs: { href: 'javascript:void(0)',
                            role: 'button'
                        }
                    }, {
                        on: {
                            'click': function click($event) {
                                for (var _len5 = arguments.length, attrs = Array(_len5 > 1 ? _len5 - 1 : 0), _key5 = 1; _key5 < _len5; _key5++) {
                                    attrs[_key5 - 1] = arguments[_key5];
                                }

                                _this2.setPage.bind(_this2, page).apply(undefined, [$event].concat(attrs));
                            }
                        }
                    }]),
                    [page]
                )]
            ));
        }.bind(this));

        return h(
            'div',
            { 'class': 'VuePagination ' + theme.wrapper },
            [h(
                'p',
                {
                    directives: [{
                        name: 'show',
                        value: parseInt(this.records)
                    }],
                    attrs: { className: 'VuePagination__count ' + theme.count }
                },
                [this.count]
            ), h(
                'ul',
                {
                    directives: [{
                        name: 'show',
                        value: this.totalPages > 1
                    }],
                    attrs: {
                        className: theme.list + ' VuePagination__pagination ' + theme.nav
                    }
                },
                [h(
                    'template',
                    {
                        directives: [{
                            name: 'if',
                            value: this.opts.edgeNavigation
                        }]
                    },
                    [firstPage]
                ), h(
                    'template',
                    {
                        directives: [{
                            name: 'if',
                            value: this.opts.chunksNavigation
                        }]
                    },
                    [prevChunk]
                ), h(
                    'li',
                    {
                        attrs: { className: 'VuePagination__pagination-item ' + theme.item + ' ' + theme.prev + ' VuePagination__pagination-item-prev-page ' + this.allowedPageClass(this.page - 1)
                        },
                        directives: [{
                            name: 'if',
                            value: this.opts.displayNextPrev
                        }]
                    },
                    [h(
                        'a',
                        (0, _babelHelperVueJsxMergeProps2.default)([{
                            attrs: { className: theme.link,
                                href: '#',
                                disabled: !!this.allowedPageClass(this.page - 1)
                            }
                        }, {
                            on: {
                                'click': function click($event) {
                                    for (var _len6 = arguments.length, attrs = Array(_len6 > 1 ? _len6 - 1 : 0), _key6 = 1; _key6 < _len6; _key6++) {
                                        attrs[_key6 - 1] = arguments[_key6];
                                    }

                                    $event.preventDefault();

                                    _this.prev.bind(_this).apply(undefined, [$event].concat(attrs));
                                }
                            }
                        }]),
                        [this.opts.texts.prev]
                    )]
                ), items, h(
                    'li',
                    {
                        attrs: { className: 'VuePagination__pagination-item ' + theme.item + ' ' + theme.next + ' VuePagination__pagination-item-next-page ' + this.allowedPageClass(this.page + 1)
                        },
                        directives: [{
                            name: 'if',
                            value: this.opts.displayNextPrev
                        }]
                    },
                    [h(
                        'a',
                        (0, _babelHelperVueJsxMergeProps2.default)([{
                            attrs: { className: theme.link,
                                href: '#',
                                disabled: !!this.allowedPageClass(this.page + 1)
                            }
                        }, {
                            on: {
                                'click': function click($event) {
                                    for (var _len7 = arguments.length, attrs = Array(_len7 > 1 ? _len7 - 1 : 0), _key7 = 1; _key7 < _len7; _key7++) {
                                        attrs[_key7 - 1] = arguments[_key7];
                                    }

                                    $event.preventDefault();

                                    _this.next.bind(_this).apply(undefined, [$event].concat(attrs));
                                }
                            }
                        }]),
                        [this.opts.texts.next]
                    )]
                ), h(
                    'template',
                    {
                        directives: [{
                            name: 'if',
                            value: this.opts.chunksNavigation
                        }]
                    },
                    [nextChunk]
                ), h(
                    'template',
                    {
                        directives: [{
                            name: 'if',
                            value: this.opts.edgeNavigation
                        }]
                    },
                    [lastPage]
                )]
            )]
        );
    };
};

==> vue-pagination-vwi-2.0.9.tgz: package/compiled/template.js <==
'use strict';

var _babelHelperVueJsxMergeProps = require('babel-helper-vue-jsx-merge-props');

var _babelHelperVueJsxMergeProps2 = _interopRequireDefault(_babelHelperVueJsxMergeProps);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = function () {

    return function (h) {
        var _this = this;

        var theme = this.Theme;
        var items = [];
        var prevChunk = '';
        var nextChunk = '';
        var firstPage = '';
        var lastPage = '';
        var prev = null;
        var next = null;

        if (this.opts.edgeNavigation && this.totalChunks > 1) {
            firstPage = h(
                'li',
                { 'class': 'VuePagination__pagination-item ' + theme.item + ' ' + (this.page === 1 ? theme.disabled : '') + ' VuePagination__pagination-item-prev-chunk' },
                [h(
                    'a',
                    (0, _babelHelperVueJsxMergeProps2.default)([{ 'class': theme.link,
                        attrs: { href: 'javascript:void(0);',
                            disabled: this.page === 1
                        }
                    }, {
                        on: {
                            'click': function click($event) {
                                for (var _len = arguments.length, attrs = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
                                    attrs[_key - 1] = arguments[_key];
                                }

                                _this.setPage.bind(_this, 1).apply(undefined, [$event].concat(attrs));
                            }
                        }
                    }]),
                    [this.opts.texts.first]
                )]
            );

            lastPage = h(
                'li',
                { 'class': 'VuePagination__pagination-item ' + theme.item + ' ' + (this.page === this.totalPages ? theme.disabled : '') + ' VuePagination__pagination-item-prev-chunk' },
                [h(
                    'a',
                    (0, _babelHelperVueJsxMergeProps2.default)([{ 'class': theme.link,
                        attrs: { href: 'javascript:void(0);',
                            disabled: this.page === this.totalPages
                        }
                    }, {
                        on: {
                            'click': function click($event) {
                                for (var _len2 = arguments.length, attrs = Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
                                    attrs[_key2 - 1] = arguments[_key2];
                                }

                                _this.setPage.bind(_this, _this.totalPages).apply(undefined, [$event].concat(attrs));
                            }
                        }
                    }]),
                    [this.opts.texts.last]
                )]
            );
        }

        if (this.opts.chunksNavigation && this.opts.chunksNavigation === 'fixed') {

            prevChunk = h(
                'li',
                { 'class': 'VuePagination__pagination-item ' + theme.item + ' ' + theme.prev + ' VuePagination__pagination-item-prev-chunk ' + this.allowedChunkClass(-1) },
                [h(
                    'a',
                    (0, _babelHelperVueJsxMergeProps2.default)([{ 'class': theme.link,
                        attrs: { href: 'javascript:void(0);',
                            disabled: !!this.allowedChunkClass(-1)
                        }
                    }, {
                        on: {
                            'click': function click($event) {
                                for (var _len3 = arguments.length, attrs = Array(_len3 > 1 ? _len3 - 1 : 0), _key3 = 1; _key3 < _len3; _key3++) {
                                    attrs[_key3 - 1] = arguments[_key3];
                                }

                                _this.setChunk.bind(_this, -1).apply(undefined, [$event].concat(attrs));
                            }
                        }
                    }]),
                    ['<<']
                )]
            );

            nextChunk = h(
                'li',
                { 'class': 'VuePagination__pagination-item ' + theme.item + ' ' + theme.next + ' VuePagination__pagination-item-next-chunk ' + this.allowedChunkClass(1) },
                [h(
                    'a',
                    (0, _babelHelperVueJsxMergeProps2.default)([{ 'class': theme.link,
                        attrs: { href: 'javascript:void(0);',
                            disabled: !!this.allowedChunkClass(1)
                        }
                    }, {
                        on: {
                            'click': function click($event) {
                                for (var _len4 = arguments.length, attrs = Array(_len4 > 1 ? _len4 - 1 : 0), _key4 = 1; _key4 < _len4; _key4++) {
                                    attrs[_key4 - 1] = arguments[_key4];
                                }

                                _this.setChunk.bind(_this, 1).apply(undefined, [$event].concat(attrs));
                            }
                        }
                    }]),
                    ['>>']
                )]
            );
        }

        this.pages.map(function (page) {
            var _this2 = this;

            items.push(h(
                'li',
                { 'class': 'VuePagination__pagination-item ' + theme.item + ' ' + this.activeClass(page) },
                [h(
                    'a',
                    (0, _babelHelperVueJsxMergeProps2.default)([{ 'class': theme.link + ' ' + this.activeClass(page),
                        attrs: { href: 'javascript:void(0)',
                            role: 'button'
                        }
                    }, {
                        on: {
                            'click': function click($event) {
                                for (var _len5 = arguments.length, attrs = Array(_len5 > 1 ? _len5 - 1 : 0), _key5 = 1; _key5 < _len5; _key5++) {
                                    attrs[_key5 - 1] = arguments[_key5];
                                }

                                _this2.setPage.bind(_this2, page).apply(undefined, [$event].concat(attrs));
                            }
                        }
                    }]),
                    [page]
                )]
            ));
        }.bind(this));

        if (this.opts.displayNextPrev) {
            prev = h(
                'li',
                {
                    attrs: { className: 'VuePagination__pagination-item ' + theme.item + ' ' + theme.prev + ' VuePagination__pagination-item-prev-page ' + this.allowedPageClass(this.page - 1) }
                },
                [h(
                    'a',
                    (0, _babelHelperVueJsxMergeProps2.default)([{
                        attrs: { className: theme.link,
                            href: '#',
                            disabled: !!this.allowedPageClass(this.page - 1)
                        }
                    }, {
                        on: {
                            'click': function click($event) {
                                for (var _len6 = arguments.length, attrs = Array(_len6 > 1 ? _len6 - 1 : 0), _key6 = 1; _key6 < _len6; _key6++) {
                                    attrs[_key6 - 1] = arguments[_key6];
                                }

                                $event.preventDefault();

                                _this.prev.bind(_this).apply(undefined, [$event].concat(attrs));
                            }
                        }
                    }]),
                    [this.opts.texts.prev]
                )]
            );
            next = h(
                'li',
                {
                    attrs: { className: 'VuePagination__pagination-item ' + theme.item + ' ' + theme.next + ' VuePagination__pagination-item-next-page ' + this.allowedPageClass(this.page + 1) }
                },
                [h(
                    'a',
                    (0, _babelHelperVueJsxMergeProps2.default)([{
                        attrs: { className: theme.link,
                            href: '#',
                            disabled: !!this.allowedPageClass(this.page + 1)
                        }
                    }, {
                        on: {
                            'click': function click($event) {
                                for (var _len7 = arguments.length, attrs = Array(_len7 > 1 ? _len7 - 1 : 0), _key7 = 1; _key7 < _len7; _key7++) {
                                    attrs[_key7 - 1] = arguments[_key7];
                                }

                                $event.preventDefault();

                                _this.next.bind(_this).apply(undefined, [$event].concat(attrs));
                            }
                        }
                    }]),
                    [this.opts.texts.next]
                )]
            );
        }

        return h(
            'div',
            { 'class': 'VuePagination ' + theme.wrapper },
            [h(
                'p',
                {
                    directives: [{
                        name: 'show',
                        value: parseInt(this.records)
                    }],
                    attrs: { className: 'VuePagination__count ' + theme.count }
                },
                [this.count]
            ), h(
                'ul',
                {
                    directives: [{
                        name: 'show',
                        value: this.totalPages > 1
                    }],
                    attrs: {
                        className: theme.list + ' VuePagination__pagination ' + theme.nav
                    }
                },
                [firstPage, prevChunk, prev, items, next, nextChunk, lastPage]
            )]
        );
    };
};
